use strict;
use warnings;

sub run_mpi_prog {

    # Purpose: runs program using mpirun. Since we are using the perl
    # system() operator, the program will wait for the job to finish
    # before proceeding.
    #
    # Input arguments
    #   $prog     - name of executable
    #   $infile   - input file
    #   $ncpu     - number of CPUs to use
    #   $outfile  - output file (redirection of stdout)
    #   $nodefile - file containing list of nodes
    #
    # Return values:
    #   none

    my ($prog, $infile, $ncpu, $outfile, $nodefile, $dryrun) = @_;

    my $time_start = time();

    my $cmd = "mpirun -np $ncpu ";
    unless ($nodefile =~ /^none$/i) {
	$cmd .= "-machinefile $nodefile ";
    }
    $cmd .= " $prog < $infile > $outfile";

    print "$cmd\n";

    my $date = localtime();

    if($dryrun) {
	$cmd = "date > $outfile";
	system($cmd);
    } else {
	system($cmd) && 
	    die "Unable to launch $prog with input $infile\n";
    }

    my $time_stop = time();
    my $time_elapsed = $time_stop - $time_start;

    my $short_prog = $prog;
    $short_prog =~ s/^.*\///;

    print OUT "Running $short_prog on $ncpu CPUs\n";
    print OUT "   input file  = $infile\n";
    print OUT "   output file = $outfile\n";
    print OUT "   run time    = $time_elapsed seconds\n";
    print OUT "\n";
}
1;
