use strict;
use warnings;

sub update_res {

    # Purpose: update the rresolutions used by programs PO2R, PSF, and
    # P3DR based on the FSC curve and values of adjustment factors
    #
    # Input arguments:
    #   $po2r_ref   - reference to hash of PO2R input parameters
    #   $p3dr_ref   - reference to hash of P3DR input parameters
    #   $psf_ref    - reference to hash of PSF input parameters
    #   $ppft_ref   - reference to hash of PPFT input parameters
    #   $auto_ref   - reference to hash of control parameters
    #   $res_locut  - resolution where FSC curve crosses fsc_locut
    #   $dryrun     - dry run flag
    #
    # Return values:
    #   None

    my ($po2r_ref, $p3dr_ref, $psf_ref, $ppft_ref, 
	$auto_ref, $res_locut, $dryrun) = @_;

    my $date = localtime();
    print OUT "Updating resolutions\n";
    print OUT "   Date = $date\n";

    # Exit early if dryrun
    if($dryrun) {
	print OUT "\n";
	return;
    }

    # Resolutions determined from $res_locut
    $$po2r_ref{res_max} = $res_locut;
    $$po2r_ref{res_max} = sprintf("%.2f", $$po2r_ref{res_max});

    $$ppft_ref{resolution_high} = $$po2r_ref{res_max};
    $$ppft_ref{resolution_high} = sprintf("%.2f", $$ppft_ref{resolution_high});

    # Tweaking to slightly higher resolution
    $$p3dr_ref{res_min} = 1/(1/$$po2r_ref{res_max}+$$auto_ref{res_adj});
    $$p3dr_ref{res_min} = sprintf("%.2f", $$p3dr_ref{res_min});

    $$psf_ref{res_max} = $$p3dr_ref{res_min};
    $$psf_ref{res_max} = sprintf("%.2f", $$psf_ref{res_max});

    # And finally slightly higher resolutions
    $$p3dr_ref{res_max} = 1/(1/$$p3dr_ref{res_min}+$$auto_ref{gauss_adj});
    $$p3dr_ref{res_max} = sprintf("%.2f", $$p3dr_ref{res_max});

    print OUT "   PO2R  res_max        changed to $$po2r_ref{res_max}\n";
    print OUT "   PPFT resolution_high changed to $$ppft_ref{resolution_high}\n";
    print OUT "   P3DR res_min         changed to $$p3dr_ref{res_min}\n";
    print OUT "   P3DR res_max         changed to $$p3dr_ref{res_max}\n";
    print OUT "   PSF  res_max         changed to $$psf_ref{res_max}\n";
    print OUT "\n";

    return;
}
1;
